@@ -9,9 +9,20 @@ from pathlib import Path
 from .config import Config
 from .mlops_client import MlopsError
 from .ml import ModelRegistry, MlopsModel
+from .rec import ChannelClient, ExperimentClient, RecommendationClient
+from .data import BatchClient, DataClient, DatasetClient, QueryClient
+
 
 MLOPS_CREDENTIALS_PATH = ".mlops/credentials"
-SERVICE_CLIENT_MAP = {}
+SERVICE_CLIENT_MAP = {
+    "channel": {"client": ChannelClient, "api_type": "REC", "path": "/channels"},
+    "experiment": {"client": ExperimentClient, "api_type": "REC", "path": "/experiments"},
+    "recommend": {"client": RecommendationClient, "api_type": "REC", "path": "/recommend"},
+    "batch": {"client": BatchClient, "api_type": "DATA", "path": "/batch"},
+    "data": {"client": DataClient, "api_type": "DATA", "path": "/data"},
+    "dataset": {"client": DatasetClient, "api_type": "DATA", "path": "/datasets"},
+    "query": {"client": QueryClient, "api_type": "DATA", "path": "/query"},
+}
 
 
 class MlopsEnv(Enum):
@@ -110,7 +121,7 @@ def client(service_name: str = None, env: str = None, apikey: str = None, runtim
     - service_name: (optional) (str) The name of a service for the client
     - env: (optional) (str) The name of a environment for mlops API (`local`|`dev`|`stg`|`prd`)
     - apikey: (optional) (str) The access apikey for mlops API
-    - runtime_env: (optional) (str) The name of a runtime environment (`local`|`edd`|`bap`)
+    - runtime_env: (optional) (str) The name of a runtime environment (`local`|`mlops`)
 
     ## Example
 
@@ -123,7 +134,7 @@ def client(service_name: str = None, env: str = None, apikey: str = None, runtim
     if env:
         assert env.upper() in MlopsEnv.list_values(), "`env` must be one of `local`|`dev`|`stg`|`prd`"
     if runtime_env:
-        assert runtime_env.upper() in RuntimeEnv.list_values(), "`runtime_env` must be one of `local`|`edd`|`bap`"
+        assert runtime_env.upper() in RuntimeEnv.list_values(), "`runtime_env` must be one of `local`|`mlops`"
 
     try:
         client_map = SERVICE_CLIENT_MAP[service_name]
@@ -132,6 +143,7 @@ def client(service_name: str = None, env: str = None, apikey: str = None, runtim
 
     config = _init_config(env=env, apikey=apikey, runtime_env=runtime_env)
     config.__setattr__("URL", config.__dict__[f"MLOPS_{client_map['api_type'].upper()}_URL"])
+    config.__setattr__("API_PATH", client_map["path"])
 
     return client_map["client"](config)
 
@@ -139,6 +151,7 @@ def client(service_name: str = None, env: str = None, apikey: str = None, runtim
 def model_registry(env: str = None, apikey: str = None, runtime_env: str = None) -> ModelRegistry:
     config = _init_config(env=env, apikey=apikey, runtime_env=runtime_env)
     config.__setattr__("URL", config.__dict__["MLOPS_DATA_URL"])
+    config.__setattr__("API_PATH", SERVICE_CLIENT_MAP["batch"]["path"])
     return ModelRegistry(config)
 
 
